#!/usr/bin/env python
"""a validating CSSParser

Usage
    parser = CSSParser()
    filename = 'test1.css'
    stylesheet = p.parse(filename, encoding)

    stylesheet.pprint(indent=2)

    # or with indent defaulting to 4
    print stylesheet.cssText 
"""
__docformat__ = 'restructuredtext'
__all__ = ['CSSParser']
__version__ = '0.8a5'


import codecs

import cssutils


class CSSParser(object):
    """
    parses a CSS StyleSheet string or file and
    returns a DOM Level 2 CSS StyleSheet object
    """

    def __init__(self, log=None, loglevel=None, raiseExceptions=False):
        """
        log
            logging object
        loglevel
            logging loglevel
        raiseExceptions
            if log should log (default) or raise
        """
        
        if log is not None:
            cssutils._log.setlog(log)

        if loglevel is not None:
            cssutils._log.setloglevel(loglevel)
            
        cssutils._log.raiseExceptions = raiseExceptions
     

    def parseString(self, cssText):
        """
        parse a CSSStyleSheet string

        cssText
            CSS string to parse        

        returns the parsed CSS as a CSSStyleSheet object
        """
        stylesheet = cssutils.css.CSSStyleSheet()
        parser = cssutils._getParser()
        stylesheet._setCssText(cssText, parser)
        return stylesheet


    def parse(self, filename, encoding='utf-8'):  
        """
        parse a CSSStyleSheet file

        filename
            name of the CSS file to parse
        encoding
            of the CSS file

        returns the parsed CSS as a CSSStyleSheet object
        """
        return self.parseString(
            codecs.open(filename, 'r', encoding).read())


if __name__ == '__main__':

    import logging
    import sys

    try:
        filename = sys.argv[1]
    except:
        print '\nusage:\n\tpython cssutils/parser.py filename.css [encoding, debug]'
        sys.exit(0)
    print 

##    newlog = logging.getLogger('CSSPARSER')
##    hdlr = logging.FileHandler('CSSPARSER.log', 'w')      
##    formatter = logging.Formatter('%(levelname)s\t%(message)s')
##    hdlr.setFormatter(formatter)
##    newlog.addHandler(hdlr)
##    newlog.setLevel(logging.DEBUG)  
##    p = CSSParser(log=newlog, loglevel=logging.DEBUG)

    if len(sys.argv) == 3 and sys.argv[2] == 'debug' or\
            len(sys.argv) == 4 and sys.argv[3] == 'debug':
        p = CSSParser(loglevel=logging.DEBUG)
    else:
        p = CSSParser()

    if len(sys.argv) > 2 and sys.argv[2] <> 'debug':      
        c = p.parse(filename, encoding=sys.argv[2])
    else:
        c = p.parse(filename)
    print 
    print c.cssText


