"""
Comment is not defined in DOM Level 2 at all, cssutils class only
implements CSSRule 
"""
__docformat__ = 'restructuredtext'
__all__ = ['Comment']
__version__ = '0.8a5'


import cssrule
import cssutils


class Comment(cssrule.CSSRule):
    """
    (cssutils)
    a CSS comment holder
    """

    type = cssrule.CSSRule.COMMENT # value = -1

    def __init__(self, cssText=u'', readonly=False, startline=1):
        self._startline = startline

        self._readonly = False
        if cssText:
            self._setCssText(cssText)
        self._readonly = readonly

        
    def getFormatted(self, indent=4, offset=0):
        "Textual representation of this comment"
        if self._cssText:
            return u'%s%s\n' % (offset*' ', self._cssText)
        else:
            return u''

    def _setCssText(self, cssText, parser=None):
        """
        cssText:
            textual text to set
        parser:
            if called from cssparser directly this is Parser instance

        DOMException on setting
         
        - SYNTAX_ERR: (P)
            Raised if the specified CSS string value has a syntax error and
            is unparsable.
        - INVALID_MODIFICATION_ERR: (P)
            Raised if the specified CSS string value represents a different
            type of rule than the current one.            
        - NO_MODIFICATION_ALLOWED_ERR: (super)
            Raised if the rule is readonly.
        """
        super(Comment, self)._setCssText(cssText)          

        if parser is None:
            parser = cssutils._getParser()

        self._cssText =\
            parser.parseCommentRule(cssText, line=self._startline)

    cssText = property(getFormatted, _setCssText,
        doc=u"(cssutils) Textual representation of this comment")
