"""
CSSUnknownRule implements DOM Level 2 CSS CSSUnknownRule.
"""
__docformat__ = 'restructuredtext'
__all__ = ['CSSUnknownRule']
__version__ = '0.8a5'


import xml.dom

import cssrule
import cssutils


class CSSUnknownRule(cssrule.CSSRule):
    """
    represents an at-rule not supported by this user agent.
    """

    type = cssrule.CSSRule.UNKNOWN_RULE


    def __init__(self, cssText=u'', readonly=False, startline=1):
        """
        cssText
            of type string
        readonly
            defaults to False              
        startline
            of this rule
        """
        self._startline = startline
        self._readonly = False

        if cssText:        
            self.cssText = cssText
        else:
            self._name = self._content = self._block = None
            
        self._readonly = readonly


    def getFormatted(self, indent=4, offset=0):
        "returns inherited property cssText prettyprinted"
        if self._name:
            cssText = u'@%s;' % self._name
            if self._content:
                cssText = u'%s %s;'% (cssText[:-1], self._content)
            if self._block:
                cssText = u'%s %s'% (cssText[:-1], self._block)
            return offset * u' ' + cssText
        else:
            return u''

    def _setCssText(self, cssText, parser=None):
        """
        DOMException on setting
        
        - SYNTAX_ERR:
          Raised if the specified CSS string value has a syntax error and
          is unparsable.
        - INVALID_MODIFICATION_ERR:
          Raised if the specified CSS string value represents a different
          type of rule than the current one.
        - HIERARCHY_REQUEST_ERR:
          Raised if the rule cannot be inserted at this point in the
          style sheet.
        - NO_MODIFICATION_ALLOWED_ERR: (self)
          Raised if the rule is readonly.
        """
        super(CSSUnknownRule, self)._setCssText(cssText)          

        if parser is None:
            parser = cssutils._getParser()
            
        name, content, block = parser.parseCSSUnknownRule(
                cssText, line=self._startline)
        self._name = name
        self._content = content
        self._block = block

    cssText = property(fget=getFormatted, fset=_setCssText,
        doc="(DOM) The parsable textual representation.")